@@ -97,6 +97,8 @@ public class EJBHelper extends AWorkbenchMOFHelper {
 	private static final JavaClass[] EMPTY_ARRAY_JAVACLASS = new JavaClass[0];
 	private static LogEntry logEntry;
 	private static Logger logger;
+	private ArtifactEdit edit = null;
+	private EJBJar ejbJar = null;
 
 	public EJBHelper() {
 		super();
@@ -169,6 +171,11 @@ public class EJBHelper extends AWorkbenchMOFHelper {
 		}
 		_dependentJavaProjects = null;
 		_javaProject = null;
+		ejbJar = null;
+		if (edit != null) {
+			edit.dispose();
+			edit = null;
+		}		
 	}
 
 	/**
@@ -532,18 +539,15 @@ public class EJBHelper extends AWorkbenchMOFHelper {
 	 */
 	public EObject loadEjbFile() {
 		
-			IVirtualComponent comp = ComponentCore.createComponent(getProject());
-			ArtifactEdit edit = ComponentUtilities.getArtifactEditForRead(comp);
-			
-			try {
-				return  ((EJBArtifactEdit) edit).asArchive(false);
-			} catch (OpenFailureException e1) {
-				Logger.getLogger().log(e1);
-			}finally {
-				if (edit != null) {
-					edit.dispose();
-				}
-			}
+		IVirtualComponent comp = ComponentCore.createComponent(getProject());
+		if( edit == null )
+			edit = ComponentUtilities.getArtifactEditForRead(comp);
+		
+		try {
+			return  ((EJBArtifactEdit) edit).asArchive(false);
+		} catch (OpenFailureException e1) {
+			Logger.getLogger().log(e1);
+		}
 		return null;		
 	}
 
@@ -551,20 +555,18 @@ public class EJBHelper extends AWorkbenchMOFHelper {
 	 * Load the EJB MOF model.
 	 */
 	public EObject loadEjbModel() {
+		if( ejbJar == null){
 			IVirtualComponent comp = ComponentCore.createComponent(getProject());
-			ArtifactEdit edit = ComponentUtilities.getArtifactEditForRead(comp);
+			edit = ComponentUtilities.getArtifactEditForRead(comp);
 			
 			try {
 				Archive archive = ((EJBArtifactEdit) edit).asArchive(false);
-				return ((EJBJarFileImpl)archive).getDeploymentDescriptor();
+				ejbJar = ((EJBJarFileImpl)archive).getDeploymentDescriptor();
 			} catch (OpenFailureException e1) {
 				Logger.getLogger().log(e1);
-			}finally {
-				if (edit != null) {
-					edit.dispose();
-				}
 			}
-		return null;		
+		}
+		return ejbJar;		
 	}
 
 	/**
