@@ -4,7 +4,7 @@
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
-* 
+ * 
  * Contributors:
  *     IBM Corporation - Initial API and implementation
  **********************************************************************/
@@ -126,6 +126,9 @@ public class Server extends Base implements IServer {
 			
 			Trace.trace(Trace.FINEST, "Auto-publish thread publishing " + Server.this);
 			
+			if (getServerState() != IServer.STATE_STARTED)
+				return;
+			
 			PublishServerJob publishJob = new PublishServerJob(Server.this, IServer.PUBLISH_AUTO, false);
 			publishJob.schedule();
 		}
@@ -485,12 +488,12 @@ public class Server extends Base implements IServer {
 		if (getServerState() != IServer.STATE_STOPPED && behaviourDelegate != null)
 			behaviourDelegate.handleResourceChange();
 		
-		if (getServerState() != IServer.STATE_STOPPED)
+		if (getServerState() == IServer.STATE_STARTED)
 			autoPublish();
 		
 		Trace.trace(Trace.FINEST, "< handleDeployableProjectChange()");
 	}
-	
+
 	protected void stopAutoPublish() {
 		if (autoPublishThread == null)
 			return;
@@ -1024,10 +1027,10 @@ public class Server extends Base implements IServer {
 		
 		if (getServerType() == null || !getServerType().supportsLaunchMode(mode2))
 			return new Status(IStatus.ERROR, ServerPlugin.PLUGIN_ID, 0, Messages.errorLaunchMode, null);
-
+		
 		return Status.OK_STATUS;
 	}
-	
+
 	public ILaunch getExistingLaunch() {
 		ILaunchManager launchManager = DebugPlugin.getDefault().getLaunchManager();
 		
@@ -1055,24 +1058,28 @@ public class Server extends Base implements IServer {
 		try {
 			getBehaviourDelegate(monitor).setupLaunchConfiguration(workingCopy, monitor);
 		} catch (Exception e) {
-			Trace.trace(Trace.SEVERE, "Error calling delegate setLaunchDefaults() " + toString(), e);
+			Trace.trace(Trace.SEVERE, "Error calling delegate setupLaunchConfiguration() " + toString(), e);
 		}
 	}
 
 	/**
 	 * Return the launch configuration for this server. If one does not exist, it
-	 * will be created if "create" is true, and otherwise will return null.
+	 * will be created if "create" is true, and otherwise will return <code>null</code>.
+	 * Will return <code>null</code> if this server type has no associated launch
+	 * configuration type (i.e. the server cannot be started).
 	 * 
 	 * @param create <code>true</code> if a new launch configuration should be
 	 *    created if there are none already
 	 * @param monitor a progress monitor, or <code>null</code> if progress
 	 *    reporting and cancellation are not desired
-	 * @return the launch configuration, no <code>null</code> if there was no
+	 * @return the launch configuration, or <code>null</code> if there was no
 	 *    existing launch configuration and <code>create</code> was false
 	 * @throws CoreException
 	 */
 	public ILaunchConfiguration getLaunchConfiguration(boolean create, IProgressMonitor monitor) throws CoreException {
 		ILaunchConfigurationType launchConfigType = ((ServerType) getServerType()).getLaunchConfigurationType();
+		if (launchConfigType == null)
+			return null;
 		
 		ILaunchManager launchManager = DebugPlugin.getDefault().getLaunchManager();
 		ILaunchConfiguration[] launchConfigs = null;
@@ -1904,18 +1911,19 @@ public class Server extends Base implements IServer {
 		//restartNeeded = wc.restartNeeded;
 		serverType = wc.serverType;
 		modules = wc.modules;
-
+		
 		// can never modify the following properties via the working copy
 		//serverState = wc.serverState;
 		delegate = wc.delegate;
 		
-		autoPublish();
+		if (getServerState() == IServer.STATE_STARTED)
+			autoPublish();
 	}
 
 	protected void saveState(IMemento memento) {
 		if (serverType != null)
 			memento.putString("server-type", serverType.getId());
-
+		
 		if (configuration != null)
 			memento.putString(CONFIGURATION_ID, configuration.getFullPath().toString());
 		else
